@@ -11,22 +11,24 @@ use PhpAmqpLib\Exception\AMQPNoDataException;
 use PhpAmqpLib\Exception\AMQPRuntimeException;
 use PhpAmqpLib\Exception\AMQPSocketException;
 use PhpAmqpLib\Exception\AMQPTimeoutException;
+use PhpAmqpLib\Helper\Assert;
+use PhpAmqpLib\Package;
 use PhpAmqpLib\Wire;
 use PhpAmqpLib\Wire\AMQPReader;
 use PhpAmqpLib\Wire\AMQPTable;
 use PhpAmqpLib\Wire\AMQPWriter;
 use PhpAmqpLib\Wire\IO\AbstractIO;
 
-class AbstractConnection extends AbstractChannel
+abstract class AbstractConnection extends AbstractChannel
 {
     /**
      * @var array
      * @internal
      */
     public static $LIBRARY_PROPERTIES = array(
-        'product' => array('S', 'AMQPLib'),
+        'product' => array('S', Package::NAME),
         'platform' => array('S', 'PHP'),
-        'version' => array('S', '2.11.0'),
+        'version' => array('S', Package::VERSION),
         'information' => array('S', ''),
         'copyright' => array('S', ''),
         'capabilities' => array(
@@ -69,7 +71,7 @@ class AbstractConnection extends AbstractChannel
     /** @var string */
     protected $known_hosts;
 
-    /** @var AMQPReader */
+    /** @var null|AMQPReader */
     protected $input;
 
     /** @var string */
@@ -82,7 +84,7 @@ class AbstractConnection extends AbstractChannel
     protected $login_method;
 
     /**
-     * @var string
+     * @var null|string
      * @deprecated
      */
     protected $login_response;
@@ -144,6 +146,18 @@ class AbstractConnection extends AbstractChannel
      */
     private $channel_rpc_timeout;
 
+    /**
+     * If connection is blocked due to the broker running low on resources.
+     * @var bool
+     */
+    protected $blocked = false;
+
+    /**
+     * If a frame is currently being written
+     * @var bool
+     */
+    protected $writing = false;
+
     /**
      * @param string $user
      * @param string $password
@@ -178,7 +192,6 @@ class AbstractConnection extends AbstractChannel
         $this->vhost = $vhost;
         $this->insist = $insist;
         $this->login_method = $login_method;
-        $this->login_response = $login_response;
         $this->locale = $locale;
         $this->io = $io;
         $this->heartbeat = $heartbeat;
@@ -189,14 +202,14 @@ class AbstractConnection extends AbstractChannel
             if ($login_method === 'PLAIN') {
                 $this->login_response = sprintf("\0%s\0%s", $user, $password);
             } elseif ($login_method === 'AMQPLAIN') {
-                $this->login_response = new AMQPWriter();
-                $this->login_response->write_table(array(
+                $login_response = new AMQPWriter();
+                $login_response->write_table(array(
                     'LOGIN' => array('S', $user),
                     'PASSWORD' => array('S', $password)
                 ));
 
                 // Skip the length
-                $responseValue = $this->login_response->getvalue();
+                $responseValue = $login_response->getvalue();
                 $this->login_response = mb_substr($responseValue, 4, mb_strlen($responseValue, 'ASCII') - 4, 'ASCII');
             } else {
                 throw new \InvalidArgumentException('Unknown login method: ' . $login_method);
@@ -216,6 +229,7 @@ class AbstractConnection extends AbstractChannel
      */
     protected function connect()
     {
+        $this->blocked = false;
         try {
             // Loop until we connect
             while (!$this->isConnected()) {
@@ -309,7 +323,7 @@ class AbstractConnection extends AbstractChannel
     protected function safeClose()
     {
         try {
-            if (isset($this->input) && $this->input) {
+            if (null !== $this->input) {
                 $this->close();
             }
         } catch (\Exception $e) {
@@ -350,7 +364,7 @@ class AbstractConnection extends AbstractChannel
     {
         $this->debug && $this->debug->debug_msg('closing input');
 
-        if (!is_null($this->input)) {
+        if (null !== $this->input) {
             $this->input->close();
             $this->input = null;
         }
@@ -359,10 +373,7 @@ class AbstractConnection extends AbstractChannel
     protected function close_socket()
     {
         $this->debug && $this->debug->debug_msg('closing socket');
-
-        if ($this->io) {
-            $this->io->close();
-        }
+        $this->io->close();
     }
 
     /**
@@ -373,6 +384,7 @@ class AbstractConnection extends AbstractChannel
         $this->debug->debug_hexdump($data);
 
         try {
+            $this->writing = true;
             $this->io->write($data);
         } catch (AMQPConnectionClosedException $e) {
             $this->do_close();
@@ -380,6 +392,8 @@ class AbstractConnection extends AbstractChannel
         } catch (AMQPRuntimeException $e) {
             $this->setIsConnected(false);
             throw $e;
+        } finally {
+            $this->writing = false;
         }
     }
 
@@ -416,7 +430,7 @@ class AbstractConnection extends AbstractChannel
      * @param string $body
      * @param AMQPWriter $pkt
      */
-    public function send_content($channel, $class_id, $weight, $body_size, $packed_properties, $body, $pkt = null)
+    public function send_content($channel, $class_id, $weight, $body_size, $packed_properties, $body, $pkt)
     {
         $this->prepare_content($channel, $class_id, $weight, $body_size, $packed_properties, $body, $pkt);
         $this->write($pkt->getvalue());
@@ -434,7 +448,7 @@ class AbstractConnection extends AbstractChannel
      * @param AMQPWriter $pkt
      * @return AMQPWriter
      */
-    public function prepare_content($channel, $class_id, $weight, $body_size, $packed_properties, $body, $pkt = null)
+    public function prepare_content($channel, $class_id, $weight, $body_size, $packed_properties, $body, $pkt)
     {
         $pkt = $pkt ?: new AMQPWriter();
 
@@ -547,8 +561,7 @@ class AbstractConnection extends AbstractChannel
      */
     protected function wait_frame($timeout = 0)
     {
-        if (is_null($this->input))
-        {
+        if (null === $this->input) {
             $this->setIsConnected(false);
             throw new AMQPConnectionClosedException('Broken pipe or closed connection');
         }
@@ -658,7 +671,7 @@ class AbstractConnection extends AbstractChannel
             // If we just queued up a method for channel 0 (the Connection
             // itself) it's probably a close method in reaction to some
             // error, so deal with it right away.
-            if ($frame_type == 1 && $frame_channel == 0) {
+            if ($frame_type === 1 && $frame_channel === 0) {
                 $this->wait();
             }
         }
@@ -678,7 +691,7 @@ class AbstractConnection extends AbstractChannel
         }
 
         $channel_id = $channel_id ? $channel_id : $this->get_free_channel_id();
-        $ch = new AMQPChannel($this->connection, $channel_id, true, $this->channel_rpc_timeout);
+        $ch = new AMQPChannel($this, $channel_id, true, $this->channel_rpc_timeout);
         $this->channels[$channel_id] = $ch;
 
         return $ch;
@@ -754,10 +767,8 @@ class AbstractConnection extends AbstractChannel
 
     /**
      * Confirm a connection close
-     *
-     * @param AMQPReader $args
      */
-    protected function connection_close_ok($args)
+    protected function connection_close_ok()
     {
         $this->do_close();
     }
@@ -784,7 +795,7 @@ class AbstractConnection extends AbstractChannel
             $wait[] = $this->waitHelper->get_wait('connection.redirect');
         }
 
-        return $this->wait($wait);
+        return $this->wait($wait, false, $this->connection_timeout);
     }
 
     /**
@@ -824,7 +835,7 @@ class AbstractConnection extends AbstractChannel
      */
     protected function connection_secure($args)
     {
-        $challenge = $args->read_longstr();
+        $args->read_longstr();
     }
 
     /**
@@ -891,7 +902,7 @@ class AbstractConnection extends AbstractChannel
 
         $v = $args->read_long();
         if ($v) {
-            $this->frame_max = $v;
+            $this->frame_max = (int)$v;
         }
 
         // use server proposed value if not set
@@ -950,6 +961,14 @@ class AbstractConnection extends AbstractChannel
         $this->io->check_heartbeat();
     }
 
+    /**
+     * @return float|int
+     */
+    public function getLastActivity()
+    {
+        return $this->io->getLastActivity();
+    }
+
     /**
      * Handles connection blocked notifications
      *
@@ -957,28 +976,30 @@ class AbstractConnection extends AbstractChannel
      */
     protected function connection_blocked(AMQPReader $args)
     {
+        $this->blocked = true;
         // Call the block handler and pass in the reason
         $this->dispatch_to_handler($this->connection_block_handler, array($args->read_shortstr()));
     }
 
     /**
      * Handles connection unblocked notifications
-     *
-     * @param AMQPReader $args
      */
-    protected function connection_unblocked(AMQPReader $args)
+    protected function connection_unblocked()
     {
+        $this->blocked = false;
         // No args to an unblock event
-        $this->dispatch_to_handler($this->connection_unblock_handler, array());
+        $this->dispatch_to_handler($this->connection_unblock_handler);
     }
 
     /**
      * Sets a handler which is called whenever a connection.block is sent from the server
      *
      * @param callable $callback
+     * @throws \InvalidArgumentException if $callback is not callable
      */
     public function set_connection_block_handler($callback)
     {
+        Assert::isCallable($callback);
         $this->connection_block_handler = $callback;
     }
 
@@ -986,9 +1007,11 @@ class AbstractConnection extends AbstractChannel
      * Sets a handler which is called whenever a connection.block is sent from the server
      *
      * @param callable $callback
+     * @throws \InvalidArgumentException if $callback is not callable
      */
     public function set_connection_unblock_handler($callback)
     {
+        Assert::isCallable($callback);
         $this->connection_unblock_handler = $callback;
     }
 
@@ -1002,6 +1025,25 @@ class AbstractConnection extends AbstractChannel
         return $this->is_connected;
     }
 
+    /**
+     * Get the connection blocked state.
+     * @return bool
+     * @since v2.12.0
+     */
+    public function isBlocked()
+    {
+        return $this->blocked;
+    }
+
+    /**
+     * Get the io writing state.
+     * @return bool
+     */
+    public function isWriting()
+    {
+        return $this->writing;
+    }
+
     /**
      * Set the connection status
      *
@@ -1048,6 +1090,14 @@ class AbstractConnection extends AbstractChannel
         return $this->server_properties;
     }
 
+    /**
+     * @return int
+     */
+    public function getHeartbeat()
+    {
+        return $this->heartbeat;
+    }
+
     /**
      * Get the library properties for populating the client protocol information
      *
@@ -1058,8 +1108,18 @@ class AbstractConnection extends AbstractChannel
         return self::$LIBRARY_PROPERTIES;
     }
 
+    /**
+     * @param array $hosts
+     * @param array $options
+     *
+     * @return mixed
+     * @throws \Exception
+     */
     public static function create_connection($hosts, $options = array()){
-        $latest_exception = null;
+        if (!is_array($hosts) || count($hosts) < 1) {
+            throw new \InvalidArgumentException('An array of hosts are required when attempting to create a connection');
+        }
+
         foreach ($hosts as $hostdef) {
             AbstractConnection::validate_host($hostdef);
             $host = $hostdef['host'];
