@@ -5,11 +5,15 @@ namespace PhpAmqpLib\Tests\Functional\Bug;
 use PhpAmqpLib\Connection\AMQPStreamConnection;
 use PHPUnit\Framework\TestCase;
 
+/**
+ * @group connection
+ * @group signals
+ */
 class Bug458Test extends TestCase
 {
     private $channel;
 
-    public function setUp()
+    protected function setUp()
     {
         if (!extension_loaded('pcntl')) {
             $this->markTestSkipped('pcntl extension is not available');
@@ -23,7 +27,9 @@ class Bug458Test extends TestCase
 
     protected function tearDown()
     {
-        $this->channel->close();
+        if ($this->channel && $this->channel->is_open()) {
+            $this->channel->close();
+        }
         $this->channel = null;
     }
 
