@@ -3,6 +3,9 @@
 namespace PhpAmqpLib\Tests\Functional\Connection;
 
 use PhpAmqpLib\Connection\AbstractConnection;
+use PhpAmqpLib\Exception\AMQPChannelClosedException;
+use PhpAmqpLib\Exception\AMQPConnectionClosedException;
+use PhpAmqpLib\Exception\AMQPHeartbeatMissedException;
 use PhpAmqpLib\Message\AMQPMessage;
 use PhpAmqpLib\Tests\Functional\AbstractConnectionTest;
 
@@ -55,27 +58,29 @@ class ConnectionClosedTest extends AbstractConnectionTest
         } catch (\Exception $exception) {
         }
 
-        $this->assertInstanceOf('Exception', $exception);
-        $this->assertInstanceOf('PhpAmqpLib\Exception\AMQPConnectionClosedException', $exception);
+        $this->assertInstanceOf(AMQPConnectionClosedException::class, $exception);
         $this->assertEquals(0, $exception->getCode());
         $this->assertChannelClosed($channel);
         $this->assertConnectionClosed($connection);
     }
 
     /**
-     * Try to write(publish) to blocked(unresponsive) connection.
+     * Try to write(publish) to blocked(unresponsive) or closed connection.
+     * Must throw correct exception for small and big data frames.
      * @test
      * @small
      * @group connection
      * @group proxy
-     * @testWith ["stream"]
-     *           ["socket"]
+     * @testWith ["stream", 1024]
+     *           ["stream", 32768]
+     *           ["socket", 32768]
      * @covers \PhpAmqpLib\Wire\IO\StreamIO::write()
      * @covers \PhpAmqpLib\Wire\IO\SocketIO::write()
      *
      * @param string $type
+     * @param int $size
      */
-    public function must_throw_exception_broken_pipe_write($type)
+    public function must_throw_exception_broken_pipe_write($type, $size)
     {
         $proxy = $this->create_proxy();
 
@@ -91,20 +96,23 @@ class ConnectionClosedTest extends AbstractConnectionTest
 
         $this->queue_bind($channel, $exchange_name = 'test_exchange_broken', $queue_name);
         $message = new AMQPMessage(
-            str_repeat('0', 1024 * 32), // 32kb fills up buffer completely on most OS
+            str_repeat('0', $size),
             ['delivery_mode' => AMQPMessage::DELIVERY_MODE_NON_PERSISTENT]
         );
 
         $exception = null;
         // block proxy connection
-        $proxy->disable();
+        $proxy->close();
+        unset($proxy);
 
         try {
             $channel->basic_publish($message, $exchange_name, $queue_name);
+        } catch (\PHPUnit_Exception $exception) {
+            throw $exception;
         } catch (\Exception $exception) {
         }
 
-        $this->assertInstanceOf('PhpAmqpLib\Exception\AMQPConnectionClosedException', $exception);
+        $this->assertInstanceOf(AMQPConnectionClosedException::class, $exception);
         $this->assertEquals(SOCKET_EPIPE, $exception->getCode());
         $this->assertChannelClosed($channel);
         $this->assertConnectionClosed($connection);
@@ -115,7 +123,91 @@ class ConnectionClosedTest extends AbstractConnectionTest
             $channel->basic_publish($message, $exchange_name, $queue_name);
         } catch (\Exception $exception) {
         }
-        $this->assertInstanceOf('PhpAmqpLib\Exception\AMQPChannelClosedException', $exception);
+        $this->assertInstanceOf(AMQPChannelClosedException::class, $exception);
+    }
+
+    /**
+     * Try to write(publish) to closed connection after missed heartbeat.
+     * @test
+     * @medium
+     * @group connection
+     * @testWith ["stream", 1024]
+     *           ["stream", 32768]
+     *           ["socket", 1024]
+     *           ["socket", 32768]
+     * @covers \PhpAmqpLib\Wire\IO\StreamIO::write()
+     * @covers \PhpAmqpLib\Wire\IO\SocketIO::write()
+     *
+     * @param string $type
+     * @param int $size
+     */
+    public function must_throw_exception_missed_heartbeat($type, $size)
+    {
+        $channel = $this->channel_create($type, [
+            'keepalive' => false,
+            'heartbeat' => $heartbeat = 1,
+            'timeout' => 3,
+        ]);
+
+        $this->queue_bind($channel, $exchange_name = 'test_exchange_broken', $queue_name);
+        $message = new AMQPMessage(
+            str_repeat('0', $size),
+            ['delivery_mode' => AMQPMessage::DELIVERY_MODE_NON_PERSISTENT]
+        );
+
+        // miss heartbeat
+        sleep($heartbeat * 2 + 1);
+
+        $exception = null;
+        try {
+            $channel->basic_publish($message, $exchange_name);
+        } catch (\PHPUnit_Exception $exception) {
+            throw $exception;
+        } catch (\Exception $exception) {
+        }
+
+        $this->assertInstanceOf(AMQPHeartbeatMissedException::class, $exception);
+        $this->assertChannelClosed($channel);
+    }
+
+    /**
+     * When client constantly publish messages in async manner and broker does not send heartbeats.
+     * @test
+     * @medium
+     * @group connection
+     * @testWith ["stream", 1024]
+     *           ["stream", 32768]
+     *           ["socket", 1024]
+     *           ["socket", 32768]
+     * @covers \PhpAmqpLib\Wire\IO\StreamIO::write()
+     * @covers \PhpAmqpLib\Wire\IO\SocketIO::write()
+     *
+     * @param string $type
+     * @param int $size
+     */
+    public function must_ignore_missing_heartbeat_after_recent_write($type, $size)
+    {
+        $channel = $this->channel_create($type, [
+            'keepalive' => false,
+            'heartbeat' => $heartbeat = 1,
+            'timeout' => 3,
+        ]);
+
+        $this->queue_bind($channel, $exchange_name = 'test_exchange_broken', $queue_name);
+        $message = new AMQPMessage(
+            str_repeat('0', $size),
+            ['delivery_mode' => AMQPMessage::DELIVERY_MODE_NON_PERSISTENT]
+        );
+
+        $iteration = 0;
+        do {
+            sleep($heartbeat);
+            $channel->basic_publish($message, $exchange_name, $queue_name);
+        } while (++$iteration <= 3);
+
+        $this->assertTrue($channel->is_open());
+        // this performs write and read with additional heartbeat check
+        $channel->close();
     }
 
     /**
@@ -165,8 +257,9 @@ class ConnectionClosedTest extends AbstractConnectionTest
         } catch (\Exception $exception) {
         }
 
-        $this->assertInstanceOf('Exception', $exception);
-        $this->assertInstanceOf('PhpAmqpLib\Exception\AMQPConnectionClosedException', $exception);
+        unset($proxy);
+
+        $this->assertInstanceOf(AMQPConnectionClosedException::class, $exception);
         $this->assertGreaterThan(0, $exception->getCode());
         $this->assertChannelClosed($channel);
         $this->assertConnectionClosed($connection);
